@@ -55,18 +55,43 @@ class TestDictionary (unittest.TestCase):
             self.assertFalse(self.oSpellChecker.isValid(sWord), sWord)
 
     def test_suggest (self):
-        for sWord in [
-            "déelirranttesss", "vallidasion", "Emilie", "exibission", "ditirembique", "jai", "email",
-            "fatiqué", "coeur", "trèèèèèèèèès", "vraaaaiiiimeeeeennnt", "apele", "email", "Co2",
-            "emmppâiiiller", "testt", "apelaion", "exsepttion", "sintaxik", "ebriete", "ennormmement"
+        for sWrong, sSugg in [
+            ("chassis", "châssis"),
+            ("francais", "français"),
+            ("déelirranttesss", "délirantes"),
+            ("vallidasion", "validation"),
+            ("Emilie", "Émilie"),
+            ("exibission", "exhibition"),
+            ("ditirembique", "dithyrambique"),
+            ("jai", "j’ai"),
+            ("email", "courriel"),
+            ("fatiqué", "fatigué"),
+            ("coeur", "cœur"),
+            ("trèèèèèèèèès", "très"),
+            ("vraaaaiiiimeeeeennnt", "vraiment"),
+            ("apele", "appel"),
+            ("Co2", "CO₂"),
+            ("emmppâiiiller", "empailler"),
+            ("testt", "test"),
+            ("apelaion", "appellation"),
+            ("exsepttion", "exception"),
+            ("sintaxik", "syntaxique"),
+            ("ebriete", "ébriété"),
+            ("ennormmement", "énormément")
         ]:
-            aSugg = self.oSpellChecker.suggest(sWord)
             #with timeblock(sWord):
-            #    aSugg = self.oSpellChecker.suggest(sWord)
-            #    print(sWord, "->", " ".join(aSugg))
+            for lSugg in self.oSpellChecker.suggest(sWrong):
+                #print(sWord, "->", " ".join(lSugg))
+                self.assertIn(sSugg, lSugg)
+
 
     def test_lemmas (self):
         for sWord, sInfi in [
+            ("suis",        "suivre"),
+            ("suis",        "être"),
+            ("a",           "avoir"),
+            ("a",           "a"),
+            ("irai",        "aller"),
             ("jetez",       "jeter"),
             ("finit",       "finir"),
             ("mangé",       "manger"),
